@@ -13,15 +13,15 @@ extern "C" {
 
 /* Enabled Extension: affinity */
 #define OMPI_HAVE_MPI_EXT_AFFINITY 1
-#include "openmpi/ompi/mpiext/affinity/c/mpiext_affinity_c.h"
+#include "openmpi/mpiext/mpiext_affinity_c.h"
 
 /* Enabled Extension: cuda */
 #define OMPI_HAVE_MPI_EXT_CUDA 1
-#include "openmpi/ompi/mpiext/cuda/c/mpiext_cuda_c.h"
+#include "openmpi/mpiext/mpiext_cuda_c.h"
 
 /* Enabled Extension: pcollreq */
 #define OMPI_HAVE_MPI_EXT_PCOLLREQ 1
-#include "openmpi/ompi/mpiext/pcollreq/c/mpiext_pcollreq_c.h"
+#include "openmpi/mpiext/mpiext_pcollreq_c.h"
 
 
 #if defined(c_plusplus) || defined(__cplusplus)
